@@ -1,6 +1,5 @@
 package Tk::SlideShow::Org;
 @Tk::SlideShow::Org::ISA = qw(Tk::SlideShow::Link);
-Tk::SlideShow::Placeable->AddClass('Tk::SlideShow::Org');
 
 sub New {
   my $class = shift;
@@ -16,8 +15,18 @@ sub trace_link {
 
   my $midy = int(($fy+$ty)/2);
   my $can = Tk::SlideShow->canvas;
-  $can->createLine($fx,$fy,$fx,$midy,$tx,$midy,$tx,$ty,-tags,$id);
+  $s->{'lineid'} = $can->createLine($fx,$fy,$fx,$midy,$tx,$midy,$tx,$ty,-tags,$id);
   return $s;
 }
 
+sub redraw {
+  my ($s,$fx,$fy,$tx,$ty) = @_;
+  my $id = $s->id;
+
+  my $midy = int(($fy+$ty)/2);
+  my $c = Tk::SlideShow->canvas;
+  $c->coords($s->{'lineid'},$fx,$fy,$fx,$midy,$tx,$midy,$tx,$ty);
+  return $s;
+}  
+
 1;
